.. include:: ../README.rst
    :start-line: 3

Why attrs?
==========

Attrs is the original python data class without boilerplate with a huge following. It
comes with features not found in the stdlib dataclasses, like keyword only arguments
and slotted classes, that won't be available until Python 3.10

It's so similar to dataclasses that also makes it the perfect candidate to test the
xsdata's plugin hooks.


.. toctree::
    :maxdepth: 1
    :hidden:

    installation
    codegen
    bindings
    changelog
    GitHub Repository <https://github.com/tefra/xsdata-attrs>


.. meta::
   :google-site-verification: VSyrlSSIOrwnZhhAo3dS6hf1efs-8FxF3KezQ-bH_js
